aboutsummaryrefslogtreecommitdiff
path: root/include/sway/desktop/transaction.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/sway/desktop/transaction.h')
-rw-r--r--include/sway/desktop/transaction.h12
1 files changed, 9 insertions, 3 deletions
diff --git a/include/sway/desktop/transaction.h b/include/sway/desktop/transaction.h
index 66e8c9a2..175489c5 100644
--- a/include/sway/desktop/transaction.h
+++ b/include/sway/desktop/transaction.h
@@ -38,11 +38,17 @@ void transaction_notify_view_ready_by_serial(struct sway_view *view,
/**
* Notify the transaction system that a view is ready for the new layout, but
* identifying the instruction by width and height rather than by serial.
*
* This is used by xwayland views, as they don't have serials.
*/
-void transaction_notify_view_ready_by_size(struct sway_view *view,
- int width, int height);
+void transaction_notify_view_ready_by_geometry(struct sway_view *view,
+ double x, double y, int width, int height);
+
+/**
+ * Unconditionally notify the transaction system that a view is ready for the
+ * new layout.
+ */
+void transaction_notify_view_ready_immediately(struct sway_view *view);
#endif
@@ -38,11 +38,17 @@ void transaction_notify_view_ready_by_serial(struct sway_view *view,
/**
* Notify the transaction system that a view is ready for the new layout, but
- * identifying the instruction by width and height rather than by serial.
+ * identifying the instruction by geometry rather than by serial.
*
* This is used by xwayland views, as they don't have serials.